/*
 * Tabs are 4 symbols wide due to stupid Windows function names...
 * ---------------------------------------------------------------
 *
 * Copyright (c) 2010 KSI Labs, LLC. All rights reserved.
 * Written by Sergey Kubushyn <ksi@koi8.net>, <ksi@ksilabs.com>.
 *
 * File: trace.h
 *
 * Debug/tracing definitions for WDM driver for KSI Labs, LLC
 * CENTIPEDE PCI Board.
 *
 * Please read documentation or go to http://www.ksilabs.com for further info.
 */

/*
 * 						LICENSE and Terms of Use.
 *
 * First of all, this is NOT GPL or Free Software. It is open so you have
 * all the source code for the Engine. There is also VHDL source code for
 * CENTIPEDE board CPLD that is available from KSI Labs, LLC website,
 * http://www.ksilabs.com.
 *
 * As for this particular code, Windows Mach3 Engine, you are free to use it,
 * make any modifications to customize it for your own needs, fix inevitable
 * bugs, port it to other CNC software and do anything else as long as your
 * derivative work that is based on this code or uses parts or pieces thereof
 * is made to be used with any KSI Labs, LLC products.
 *
 * We do NOT grant you a permission to use any parts of this software in any
 * products that are designed for products not manufactured or distributed
 * by KSI Labs, LLC. We might give such a permission on case-by-case basis
 * but it is not legal to use this software or bits and pieces thereof with
 * products not coming from KSI Labs, LLC without our explicit written
 * permission.
 *
 * The original copyright notices must be included in all derivative works.
 * You do NOT have to ask our permission to make any modifications to this
 * code and you are not under obligation to give us any of your work back
 * as long as you are using it for your own needs.
 *
 * However we do NOT give our permission to distribute your derivative work
 * unless all original copyrights are retained, all the conditions of this
 * license are met (use only with KSI Labs, LLC products) and full source
 * code for such derivative work is available for free to everybody without
 * any further conditions including but not limited to signing any kinds of
 * NDA. We explicitely deny permission to distribute any derivative work
 * based on this code with closed source binary-only fragments or include
 * bits or pieces of this code in such products.
 *
 * CNC software like Mach3 and likes is excluded from these requirements as
 * long as it does not include parts or pieces of this software into the
 * close source proprietary application proper. It can use shared memory
 * buffer, IOCTL calls, etc. to communicate with this Engine or the one based
 * on it and keep all the software making those calls or working on that
 * buffer close source and proprietary as long as those calls/structures are
 * documented and that documentation is freely available to everybody without
 * any further conditions including but no limited to signing any kind of NDA.
 */

/*
 * We do not use event tracing, everything goes to kernel debugger.
 */
#ifndef _TRACE_H_
#define _TRACE_H_

// Uncomment this if you want debugging info
//
//#define DEBUG	1

#ifdef DEBUG
//
// Define debug levels
//
#define     OFF        0	// Tracing is not o
#define     FATAL      1	// Abnormal exit or termination
#define     ERROR      2	// Severe errors that need logging
#define     WARNING    3	// Warnings such as allocation failure
#define     INFO       4	// Includes non-error cases such as Entry-Exit
#define     TRACE      5	// Detailed traces from intermediate steps
#define     LOUD       6	// Detailed trace from every step

//
// Change this if different debug level or flags required
//
#define DBG_LEVEL		LOUD
#define DBG_FLAGS		0xFFFFFFFF

//
// Define Debug Flags
//
#define DBG_INIT	  		0x00000001
#define DBG_PNP			    0x00000002
#define DBG_POWER           0x00000004
#define DBG_WMI             0x00000008
#define DBG_CREATE_CLOSE    0x00000010
#define DBG_IOCTLS          0x00000020
#define DBG_WRITE           0x00000040
#define DBG_READ            0x00000080
#define DBG_DPC             0x00000100
#define DBG_INTERRUPT       0x00000200
#define DBG_LOCKS           0x00000400
#define DBG_QUEUEING        0x00000800
#define DBG_HW_ACCESS       0x00001000
#define DBG_PLANNED_MOTION	0x00002000

VOID DebugPrint(ULONG PrintLevel, ULONG PrintFlag, PCCHAR Message, ...);
#endif	// DEBUG
#endif	// _TRACE_H_
